@@ -3,10 +3,17 @@
 use strict;
 use IO::Handle;
 
-my $in  = "prefs.in";
-my $h   = "prefs.h";
-my $cpp = "prefs.cpp";
+my $srcdir=$ARGV[0];
+if(! defined($srcdir))
+{
+	print "srcdir not defined, using avidemux\n";
+	$srcdir="avidemux";
+}
 
+my $in  = "$srcdir/prefs.in";
+my $h   = "$srcdir/prefs.h";
+my $cpp = "$srcdir/prefs.cpp";
+#print "In:$in\n";
 my $h_str = "typedef enum {\n";
 my $cpp_str = "typedef enum {\n".
               "\tUINT,\n".
@@ -14,7 +21,8 @@ my $cpp_str = "typedef enum {\n".
               "\tULONG,\n".
               "\tLONG,\n".
               "\tFLOAT,\n".
-              "\tSTRING\n".
+              "\tSTRING,\n".
+              "\tFILENAME\n".
               "} types;\n".
               "\n".
               "typedef struct {\n".
@@ -46,7 +54,7 @@ while(<$fd>){
 		$cpp_str .= "\t{\"$N\",";
 		$cpp_str .= "\t" if( length($c)%8 != 3 );
 		$cpp_str .= "\t$b,";
-		if( $b eq "STRING" ){
+		if(( $b eq "STRING" )||($b eq "FILENAME")){
 			$c =~ s/^"//;
 			$c =~ s/"$//;
                         $c =~ s/@/,/; # Replace % by , needed by alsa stuff
@@ -58,7 +66,7 @@ while(<$fd>){
 		$cpp_str .= "\t" if( length($c) < 5 );
 		$cpp_str .= "NULL,";
 		# max min processing
-		if( $b eq "STRING" ){
+		if(( $b eq "STRING" )||($b eq "FILENAME")){
 			$cpp_str .= " NULL, NULL },\n";
 		}else{
 			$d =~ s/^\s*,\s*//;
