@@ -98,16 +98,17 @@ protected:
          uint32_t  nbAudioTrack;
 	 uint32_t *Sz,*Co,*Sc;
 	 uint32_t *Sn,*Sync;
-	 uint32_t *SttsN,*SttsC;
+	 uint32_t *SttsN,*SttsC,*Ctts,nbCtts;
 
 
 	uint8_t		buildIndex(	_3gpTrack *track,
 					uint32_t scale,
-					uint32_t nbSz,		uint32_t *Sz,
+					uint32_t nbSz,		uint32_t *Sz, uint32_t szIndentical,
 					uint32_t nbChunk ,	uint32_t *Chunk,
 					uint32_t nbSc,		uint32_t *Sc,
 					uint32_t nbStts,uint32_t *SttsN,uint32_t *SttsC,
-					uint32_t *Sn,			uint32_t *outNbChunk
+					uint32_t *Sn,			uint32_t *outNbChunk,
+                                            uint32_t isAudio
 					);
 	uint32_t 		readPackedLen(adm_atom *tom );
 	
@@ -118,7 +119,7 @@ virtual   uint32_t 			getNbStream(void) ;
 virtual   uint8_t 			needDecompress(void) { return 1;};
 
 			_3GPHeader( void ) ;
-       		    	~_3GPHeader(  ) ;
+                        virtual	~_3GPHeader(  ) ;
 // AVI io
 virtual 	uint8_t			open(char *name);
 virtual 	uint8_t			close(void) ;
@@ -147,7 +148,7 @@ virtual 	uint8_t  	getFrameNoAlloc(uint32_t framenum,uint8_t *ptr,uint32_t* fram
 // Multi track
 uint8_t        changeAudioStream(uint32_t newstream);
 uint32_t     getCurrentAudioStreamNumber(void);
-uint8_t     getAudioStreamsInfo(uint32_t *nbStreams, uint32_t **infos);
+uint8_t     getAudioStreamsInfo(uint32_t *nbStreams, audioInfo **infos);
 uint8_t      isReordered( void );
 uint8_t      reorder( void );
 
