@@ -37,7 +37,7 @@ extern "C"
 {
 #include "common.h"
 #include "bswap.h"
-#include "../../adm_lavcodec/bitstream.h"
+#include "ADM_lavcodec/bitstream.h"
 }
 /*
     Extract width & height from vol header passed as arg
