@@ -216,8 +216,10 @@ rebranch2:
 
 		switch (c)
 		  {
+#ifndef FALSE_ALARM
 		  case 0xff:
 		      goto rebranch2;
+#endif
 		  case 0xfa:
 		  case 0xfb:
          	  case 0xfc:
@@ -225,6 +227,9 @@ rebranch2:
    		  case 0xf3:
                   case 0xf4:
 	     	  case 0xf5:
+#ifdef FALSE_ALARM
+                  case 0xff:
+#endif
 		  	// For mpeg1/2 layer 1/2 (svcd/VCD/DVD)
 			// We make some extra check to avoid cutting
 			// on a falsely detected mpeg frame that would
@@ -296,7 +301,7 @@ uint8_t AVDMGenericAudioStream::beginDecompress(void)
 //
 //__________________________________________
 uint32_t AVDMGenericAudioStream::readDecompress(uint32_t size,
-						uint8_t * ptr)
+						uint8_t * ptr)//deprecate
 {
     uint32_t rd = 0, d = 0, in = 0,samples=0;
     uint8_t r=0;
@@ -316,7 +321,7 @@ drop:
 			printf(" read failed, end of stream ? \n");
 			return rd;
                	}
-		if(!_codec->run(internalBuffer,in,ptr+rd,&d))
+//		if(!_codec->run(internalBuffer,in,ptr+rd,&d))
 		{
 			printf("\n Codec error !!!!!!!!!!!!!!!!!!!!!!!!!!!\n");
 			goto drop;
@@ -329,6 +334,36 @@ drop:
 
 }
 
+uint32_t AVDMGenericAudioStream::readDecompress(uint32_t size, float *ptr)
+{
+	uint32_t rd = 0, d = 0, in = 0,samples=0;
+	uint8_t r = 0;
+	// Paranoia check
+	ADM_assert(_wavheader);
+	ADM_assert(_codec);
+	ADM_assert(isDecompressable());
+
+	while(rd<size)
+	{
+		// Read from stream
+		r=getPacket(internalBuffer, &in, &samples);
+		if (!r) {
+drop:
+			printf(" read failed, end of stream ? \n");
+			return rd;
+		}
+		if (!_codec->run(internalBuffer,in,ptr+rd,&d))
+		{
+			printf("\n Codec error !!!!!!!!!!!!!!!!!!!!!!!!!!!\n");
+			goto drop;
+		}
+		if (d)
+			rd+=d;
+	}
+
+	return rd;
+}
+
 //________________________________________________________________
 //   Returns 1 if audio is compressed else 0
 //________________________________________________________________
