@@ -25,6 +25,7 @@
 #include "fourcc.h"
 #include "ADM_audio/aviaudio.hxx"
 #include "ADM_audiocodec/ADM_audiocodec.h"
+#include "ADM_audiofilter/audiofilter_channel_route.h"
 
 
 ADM_Audiocodec	*getAudioCodec(uint32_t fourcc,WAVHeader *info,uint32_t extra,uint8_t *extraData)
@@ -79,9 +80,15 @@ ADM_Audiocodec *out;
 				case WAV_AC3:
         				printf("\n Audio codec:  AC3\n");
 
-					out= (ADM_Audiocodec *) new ADM_AudiocodecAC3(fourcc);
+					out= (ADM_Audiocodec *) new ADM_AudiocodecAC3(fourcc, info);
                   break;
 #endif
+#ifdef USE_LIBDCA
+                                case WAV_DTS:
+                                    printf("\n Audio codec:  DTS\n");
+                                    out= (ADM_Audiocodec *) new ADM_AudiocodecDCA(fourcc, info);
+                                    break;
+#endif
 #ifdef USE_MP3
 				case WAV_MP3:
 				case WAV_MP2:
@@ -110,47 +117,30 @@ ADM_Audiocodec *out;
 						printf("\n ULAW codec\n");
 						out=(ADM_Audiocodec *) new ADM_AudiocodecUlaw(fourcc,info);
 						break;
-              	case WAV_WMA:
-        				printf("\n Audio codec:  ffWMA\n");
-				
-					out= (ADM_Audiocodec *) new ADM_AudiocodecWMA(fourcc,info,extra,extraData);
-                  break;
-		  
-            	default:
+            case WAV_WMA:
+                printf("\n Audio codec:  ffWMA\n");
+                out= (ADM_Audiocodec *) new ADM_AudiocodecWMA(fourcc,info,extra,extraData);
+                break;
+            case WAV_QDM2:
+                printf("\n Audio codec:  ffQDM2\n");
+                out= (ADM_Audiocodec *) new ADM_AudiocodecWMA(fourcc,info,extra,extraData);
+                break;
+            default:
              			printf("\n Unknown codec : %lu",fourcc);
              			out= (ADM_Audiocodec *) new ADM_AudiocodecUnknown(fourcc);
         	}
 
+	ch_route.input_type[0] = CH_FRONT_LEFT;
+	ch_route.input_type[1] = CH_FRONT_RIGHT;
+
          return out;
-
-
 }
 
 ADM_Audiocodec::ADM_Audiocodec( uint32_t fourcc ) {
     UNUSED_ARG(fourcc);
-	_running=0;
 	_init=0;
 }
 
 ADM_Audiocodec::~ADM_Audiocodec()
 {}
 
-uint8_t ADM_Audiocodec::run( uint8_t * ptr, uint32_t nbIn, uint8_t * outptr,   uint32_t * nbOut){
-    UNUSED_ARG(ptr);
-    UNUSED_ARG(nbIn);
-    UNUSED_ARG(outptr);
-    UNUSED_ARG(nbOut);
-	return 0;
-}
-
-
-ADM_AudiocodecUnknown::~ADM_AudiocodecUnknown(){
-}
-
-uint8_t ADM_AudiocodecUnknown::run( uint8_t * ptr, uint32_t nbIn, uint8_t * outptr,   uint32_t * nbOut){
-    UNUSED_ARG(ptr);
-    UNUSED_ARG(nbIn);
-    UNUSED_ARG(outptr);
-    UNUSED_ARG(nbOut);
-	return 0;
-}
