@@ -19,10 +19,12 @@ typedef struct {
 #ifdef USE_VORBIS
                 {"vorbis","Vorbis", AUDIOENC_VORBIS},
 #endif
-
+#ifdef USE_AFTEN
+                {"aften","Aften", AUDIOENC_AFTEN},
+#endif
                 {"mp2", "FFm MP2", AUDIOENC_MP2},
                 {"ac3", "FFm AC3",AUDIOENC_AC3},
-                {"toolame","Toolame", AUDIOENC_2LAME},
+                {"twolame","Twolame", AUDIOENC_2LAME},
                 {"none", "Wav PCM",AUDIOENC_NONE},
                 {"lpcm", "Wav LPCM",AUDIOENC_LPCM}
 };
