@@ -34,6 +34,7 @@
 
 #define _context ((AVCodecContext *)_contextVoid)
 
+uint8_t scratchPad[SCRATCH_PAD_SIZE];
 
    uint8_t ADM_AudiocodecWMA::beginDecompress( void ) 
    {
@@ -50,34 +51,42 @@
        :  ADM_Audiocodec(fourcc)
  {
     _tail=_head=0;
-    ADM_assert(fourcc==WAV_WMA);	
+    ADM_assert(fourcc==WAV_WMA || fourcc==WAV_QDM2);	
     _contextVoid=(void *)avcodec_alloc_context();
     ADM_assert(_contextVoid);
     // Fills in some values...
     _context->sample_rate = info->frequency;
-    
     _context->channels = info->channels;
-    /*
-    _context->bit_rate = info->byterate<<3; // byte -> bits
-    */
-//    _context->fourcc = fourcc;
-    _context->block_align = info->blockalign;       // ...
-    _context->codec_id = CODEC_ID_WMAV2;
-    _blockalign=info->blockalign;
-  
+    _blockalign=_context->block_align = info->blockalign;
+    _context->bit_rate = info->byterate*8;
+    if(fourcc==WAV_WMA)
+        _context->codec_id = CODEC_ID_WMAV2;
+    else
+        if(fourcc==WAV_QDM2)
+        _context->codec_id = CODEC_ID_QDM2;
+            else ADM_assert(0);
+
     _context->extradata=(void *)d;
     _context->extradata_size=(int)l;
-
     printf(" Using %ld bytes of extra header data\n",l);
     mixDump((uint8_t *)_context->extradata,_context->extradata_size);
 
-   AVCodec *codec=avcodec_find_decoder(CODEC_ID_WMAV2);
-   if(!codec) {GUI_Error_HIG("Internal error", "Cannot open WMA2 codec.");ADM_assert(0);} 
+   AVCodec *codec=avcodec_find_decoder(_context->codec_id);
+   if(!codec) {GUI_Error_HIG(_("Internal error"), _("Cannot open WMA2 codec."));ADM_assert(0);} 
     if (avcodec_open(_context, codec) < 0)
     {
         printf("\n WMA decoder init failed !\n");
         ADM_assert(0);
     }
+    if(!_blockalign)
+    { 
+      if(_context->block_align) _blockalign=_context->block_align;
+      else
+      {
+        printf("FFWMA : no blockalign taking 378\n");
+        _blockalign=378;   
+      }
+    }
     printf("FFwma init successful (blockalign %d)\n",info->blockalign);
 }
  ADM_AudiocodecWMA::~ADM_AudiocodecWMA()
@@ -89,10 +98,12 @@
 /*-------------------------------------------------------------------------------------------------------------------------
 -------------------------------------------------------------------------------------------------------------------------*/
 
-uint8_t ADM_AudiocodecWMA::run( uint8_t * ptr, uint32_t nbIn, uint8_t * outptr,   uint32_t * nbOut)
+uint8_t ADM_AudiocodecWMA::run(uint8_t *inptr, uint32_t nbIn, float *outptr, uint32_t *nbOut)
 {
 int out=0;
 int max=0,pout=0;
+int16_t *run16;
+int nbChunk;
 
         *nbOut=0;
         // Shrink
@@ -104,24 +115,38 @@ int max=0,pout=0;
         }
         //
         ADM_assert(nbIn+_tail<ADMWA_BUF);
-        memcpy(_buffer+_tail,ptr,nbIn);
+        memcpy(_buffer+_tail,inptr,nbIn);
         _tail+=nbIn;
-        while(_tail-_head>_blockalign)
+        while(_tail-_head>=_blockalign)
         {
-                out=avcodec_decode_audio(_context,(int16_t *)outptr,&pout,_buffer+_head,_tail-_head);
-                //printf("Align:%d In: %d out:%d\n",_blockalign,out,pout);
-                if(out<0)
-                {
-                        printf( " *** WMA decoding error ***\n");
-                        _head+=1; // Try skipping some bytes
-                        continue;
-                }
-            
-                _head+=out; // consumed bytes
-                *nbOut+=pout;
-                outptr+=pout;
-
+          nbChunk=(_tail-_head)/_blockalign;
+          pout=SCRATCH_PAD_SIZE;
+          out=avcodec_decode_audio(_context,(int16_t *)scratchPad,
+                                   &pout,_buffer+_head,nbChunk*_blockalign);
+                
+          if(out<0)
+          {
+            printf( " *** WMA decoding error (%u)***\n",_blockalign);
+            _head+=1; // Try skipping some bytes
+            continue;
+          }
+          if(pout>=SCRATCH_PAD_SIZE)
+          {
+            printf("Produced : %u, buffer %u,in%u\n",pout,SCRATCH_PAD_SIZE,_tail-_head);
+            ADM_assert(0); 
+          }
+          _head+=out; // consumed bytes
+          pout>>=1;
+          *nbOut+=pout;
+          run16=(int16_t *)scratchPad;
+          for(int i=0;i<pout;i++)
+          {
+            *outptr++=((float)run16[i])/32767.;
+          }
         }
+        
+        
+        
         return 1;
 }
 ///************************************************
@@ -135,7 +160,7 @@ int max=0,pout=0;
             _tail=_head=0;
             return 1;
    };
-   
+/* AMR specific */
  ADM_AudiocodecAMR::ADM_AudiocodecAMR(uint32_t fourcc,WAVHeader *info)
        :  ADM_Audiocodec(fourcc)
  {
@@ -154,7 +179,7 @@ int max=0,pout=0;
         printf(" Opening AMR codec\n");
 
         AVCodec *codec=avcodec_find_decoder(CODEC_ID_AMR_NB);
-        if(!codec) {GUI_Error_HIG("Internal error", "Cannot open AMR codec.");ADM_assert(0);} 
+        if(!codec) {GUI_Error_HIG(_("Internal error"), _("Cannot open AMR codec."));ADM_assert(0);} 
         if (avcodec_open(_context, codec) < 0)
         {
             printf("\n AMR decoder init failed !\n");
@@ -171,13 +196,15 @@ int max=0,pout=0;
 /*-------------------------------------------------------------------------------------------------------------------------
 -------------------------------------------------------------------------------------------------------------------------*/
 #define AMR_PACKET 32
-uint8_t ADM_AudiocodecAMR::run( uint8_t * ptr, uint32_t nbIn, uint8_t * outptr,   uint32_t * nbOut)
+uint8_t ADM_AudiocodecAMR::run(uint8_t *inptr, uint32_t nbIn, float *outptr, uint32_t *nbOut)
 {
 int out;
-int max=0,pout=0,toread;
-	
-	*nbOut=0;
-	// Shrink
+int pout=0;
+int16_t *run16;
+
+
+        *nbOut=0;
+        // Shrink
         if(_head && (_tail+nbIn)*3>ADM_AMR_BUFFER*2)
         {
             memmove(_buffer,_buffer+_head,_tail-_head);
@@ -186,24 +213,31 @@ int max=0,pout=0,toread;
         }
         //
         ADM_assert(nbIn+_tail<ADM_AMR_BUFFER);
-        memcpy(_buffer+_tail,ptr,nbIn);
+        memcpy(_buffer+_tail,inptr,nbIn);
         _tail+=nbIn;
         while(_tail-_head>AMR_PACKET)
         {
-                out=avcodec_decode_audio(_context,(int16_t *)outptr,&pout,_buffer+_head,_tail-_head);
+          out=avcodec_decode_audio(_context,(int16_t *)scratchPad,
+                                   &pout,_buffer+_head,_tail-_head);
                 
                 if(out<0)
                 {
-                        printf( " *** WMA decoding error ***\n");
+                        printf( " *** AMR decoding error ***\n");
                         _head+=1; // Try skipping some bytes
                         continue;
                 }
             
                 _head+=out; // consumed bytes
+                pout>>=1;
                 *nbOut+=pout;
-                outptr+=pout;
-
+                run16=(int16_t *)scratchPad;
+                for(int i=0;i<pout;i++)
+                {
+                  *outptr++=((float)run16[i])/32767.;
+                }
         }
+        
+
         return 1;
 }
 
