@@ -39,6 +39,7 @@
 #include "fourcc.h"
 #include "ADM_audio/aviaudio.hxx"
 #include "ADM_audiocodec/ADM_audiocodec.h"
+#include "ADM_audiofilter/audiofilter_channel_route.h"
 
 #ifdef USE_VORBIS
 
@@ -145,11 +146,16 @@
 	STRUCT->ampscale=1;
 	_init=1;
 
- 
+	ch_route.input_type[0] = CH_FRONT_LEFT;
+	ch_route.input_type[1] = CH_FRONT_RIGHT;
+	ch_route.input_type[2] = CH_REAR_LEFT;
+	ch_route.input_type[3] = CH_REAR_RIGHT;
+	ch_route.input_type[4] = CH_FRONT_CENTER;
+	ch_route.input_type[5] = CH_LFE;
  }
  // This codec expects more or less one packet at a time !
  
- uint8_t ADM_vorbis::run( uint8_t * ptr, uint32_t nbIn, uint8_t * outptr,   uint32_t * nbOut)
+ uint8_t ADM_vorbis::run(uint8_t *inptr, uint32_t nbIn, float *outptr, uint32_t *nbOut)
 {
 ogg_packet packet;
 float **sample_pcm;
@@ -160,7 +166,7 @@ int	nb_synth;
 	packet.b_o_s=0;
 	packet.e_o_s=0;
 	packet.bytes=nbIn;
-	packet.packet=ptr;
+	packet.packet=inptr;
         packet.granulepos=-1;
 	if(!vorbis_synthesis(&STRUCT->vblock,&packet))
 	{
@@ -173,31 +179,12 @@ int	nb_synth;
 		return 0;
 	 }
 	 
-	 // Now convert the float / per channel samples to interleaved 16 bits pcm audio
- 
- 	 float scale =   32767.f * STRUCT->ampscale;
-	 int16_t *out;
-	 int channels,val;	 
+	 for (uint32_t samp = 0; samp < nb_synth; samp++)
+	 	for (uint8_t chan = 0; chan < STRUCT->vinfo.channels; chan++)
+			*outptr++ = sample_pcm[chan][samp] * STRUCT->ampscale;
+
+	 *nbOut = STRUCT->vinfo.channels * nb_synth;
 
-	 
-	 channels=STRUCT->vinfo.channels;
-	 out=(int16_t *)outptr;
-	 *nbOut=channels*2*nb_synth;
-	 
-	 for(uint32_t samp=0;samp<nb_synth;samp++)
-	 {
-	 for(uint32_t chan=0;chan<channels;chan++)
-	 {
-	 	     
-	        val=(int)floor(sample_pcm[chan][samp]*scale);
-		
-		if(val>32767)	
-		  	val=32767;
-		if(val<-32768)
-		  	val=-32768;
-		*out++=val;      
-	  }
-	  }
 	// Puge them
 	 vorbis_synthesis_read(&STRUCT->vdsp,nb_synth); 
 	 aprintf("This round : in %d bytes, out %d bytes synthetized:%d\n",nbIn,*nbOut,nb_synth);
