@@ -28,6 +28,7 @@
 #include "prefs.h"
 #ifdef HAVE_AUDIO
 #include "ADM_assert.h"
+#include "ADM_audiodevice.h"
 
 #include "ADM_audiodevice/ADM_deviceoss.h"
 
@@ -51,15 +52,25 @@
 #include "ADM_deviceEsd.h"
 #endif
 
+#ifdef CONFIG_DARWIN
+#include "ADM_audiodevice/ADM_deviceAudioCore.h"
+#endif
+
 #include "gui_action.hxx"
 #include "audio_out.h"
 
+
+
+
+
+audioDevice::audioDevice(void) {
+}
+
 /**
 		in=0 -> arts1
 		in=1 -> alsa
 */
 
-
 audioDevice *device=NULL;
 static AUDIO_DEVICE  currentDevice=DEVICE_DUMMY;
 static AUDIO_DEVICE ADM_audioByName(const char *name);
@@ -247,9 +258,9 @@ void AVDM_AudioClose(void)
 //
 //
 //_______________________________________________
-uint32_t AVDM_AudioSetup(uint32_t fq, uint32_t channel)
+uint32_t AVDM_AudioSetup(uint32_t fq, uint8_t channel)
 {
-	if(channel>2) channel=2;
+	
 	return device->init(channel,fq);
 }
 uint8_t         AVDM_setVolume(int volume)
@@ -263,7 +274,7 @@ uint8_t         AVDM_setVolume(int volume)
 //
 //
 //_______________________________________________
-uint8_t AVDM_AudioPlay(uint8_t * ptr, uint32_t nb)
+uint8_t AVDM_AudioPlay(float *ptr, uint32_t nb)
 {
 	return device->play(nb,ptr);
 }
