@@ -20,10 +20,10 @@ class esdAudioDevice : public audioDevice
 		 protected :
                     int esdDevice;
 		  public:
-		  			esdAudioDevice(void) { esdDevice=-1;}
-		     		virtual uint8_t init( uint32_t channel,uint32_t fq ) ;
-	    			virtual uint8_t play( uint32_t len, uint8_t *data ) ;
-		      		virtual uint8_t stop( void ) ;
+		  			esdAudioDevice(void) {esdDevice=-1;}
+		     		virtual uint8_t init(uint8_t channels, uint32_t fq);
+	    			virtual uint8_t play(uint32_t len, float *data);
+		      		virtual uint8_t stop(void);
 				uint8_t setVolume(int volume);
 		 }     ;
 #endif
