@@ -15,11 +15,11 @@
 		 protected :
 					uint8_t				_inUse;
 		  public:
-		  				win32AudioDevice(void) ;
-		     		virtual uint8_t init( uint32_t channel,uint32_t fq ) ;
-	    			virtual uint8_t play( uint32_t len, uint8_t *data ) ;
-		      		virtual uint8_t stop( void ) ;
-		      		virtual uint8_t setVolume( int volume ) ;
+		  				win32AudioDevice(void);
+		     		virtual uint8_t init(uint8_t channels, uint32_t fq);
+	    			virtual uint8_t play(uint32_t len, float *data);
+		      		virtual uint8_t stop(void);
+		      		virtual uint8_t setVolume(int volume);
 		 }     ;
 
 #endif
