@@ -40,6 +40,7 @@
 #include "ADM_toolkit/toolkit.hxx"
 #include <ADM_assert.h>
 #include "ADM_codecs/ADM_ffmpeg.h"
+#include "ADM_toolkit/ADM_cpuCap.h"
 //#define TEST_NOB 1
 
 static char LogName[500];
@@ -47,12 +48,49 @@ static char LogName[500];
 #define WRAP_Open(x) \
 {\
 AVCodec *codec=avcodec_find_encoder(x);\
-if(!codec) {GUI_Alert("Internal error opening codec"#x);ADM_assert(0);} \
+if(!codec) {GUI_Alert(_("Internal error opening codec"#x));ADM_assert(0);} \
   res=avcodec_open(_context, codec); \
-  if(res<0) {GUI_Alert("Internal error with context for  codec"#x);ADM_assert(0);} \
-} 
+  if(res<0) {GUI_Alert(_("Internal error with context for  codec"#x".\n Did you use too low / too high target for 2 pass ?"));return 0;} \
+}
+/*****************************************/
+uint8_t ffmpegEncoder::stopEncoder(void)
+{
+    printf("[lavcodec] stopEncoder (%x)\n",_context);
+    if (_init)
+    {
+        _init = 0;
+        avcodec_close (_context);
+        ADM_dealloc (_context);
+        _context = NULL;
+    }
+    return 1;
+}
+/*****************************************/
+ffmpegEncoderCQ::~ffmpegEncoderCQ ()
+  {
+    printf("Deleting ffmpegCQencoder\n");
+    //stopEncoder ();
+    if (_statfile)
+      {
+        fflush(_statfile);
+	fclose (_statfile);
+      }
+  }
+/*****************************************/
+void ffmpegEncoder::postAmble (ADMBitstream * out, uint32_t sz)
+{
+  out->ptsFrame = _context->coded_frame->display_picture_number; //real_pict_num;;
+ //printf("Out : %u\n",out->ptsFrame);
+  out->len = (uint32_t) sz;
+  out->flags = frameType ();;
+  if(!_context->coded_frame->quality)
+      out->out_quantizer=(int) floor (_frame.quality / (float) FF_QP2LAMBDA);
+  else
+      out->out_quantizer =(int) floor (_context->coded_frame->quality / (float) FF_QP2LAMBDA);
 
-static myENC_RESULT res;
+}
+//static myENC_RESULT res;
+/*****************************************/
 ffmpegEncoder::ffmpegEncoder (uint32_t width, uint32_t height, FF_CODEC_ID id):encoder (width,
 	 height)
 {
@@ -73,19 +111,37 @@ ffmpegEncoder::ffmpegEncoder (uint32_t width, uint32_t height, FF_CODEC_ID id):e
   _frame.linesize[0] = _w;
   _frame.linesize[1] = _w >> 1;
   _frame.linesize[2] = _w >> 1;
+  _isMT = 0;
 
 };
+/*****************************************/
+uint8_t   ffmpegEncoder::encode(ADMImage *in,ADMBitstream *out)
+{
+    int32_t sz = 0;
+    ADM_assert(out->bufferSize);
+    encodePreamble (in->data);
+    if ((sz = avcodec_encode_video (_context, out->data, out->bufferSize, &_frame)) < 0)
+        return 0;
+    postAmble(out,sz);
+    return 1;
+}
+/*****************************************/
+ffmpegEncoder::~ffmpegEncoder ()
+{
+  printf ("[codec] FF base encoder destroying..\n");
+  if (_isMT)
+    {
+      printf ("[codec] killing threads\n");
+      avcodec_thread_free (_context);
+      _isMT = 0;
+    }
+  stopEncoder ();
+}
 
 /*
    	Initialize codec in Q mode
 
 */
-uint8_t
-ffmpegEncoder::getResult (void *ress)
-{
-  memcpy (ress, &res, sizeof (res));
-  return 1;
-}
 
 uint8_t
 ffmpegEncoder::encodePreamble (uint8_t * in)
@@ -105,7 +161,7 @@ ffmpegEncoder::encodePreamble (uint8_t * in)
 
   _frame.key_frame = 0;
   _frame.pict_type = 0;
-  _frame.quality = 0;
+// No!  _frame.quality = 0;
   return 1;
 }
 
@@ -137,13 +193,13 @@ ffmpegEncoder::gopMpeg1 (void)
 {
   // small gop, 2 b frames allowed
   // min bitrate 500 max bitrate 2200
-int rate;
+  int rate;
 
-        rate=_context->time_base.den;
-        rate=rate*1000;
-        rate/=_context->time_base.num;
+  rate = _context->time_base.den;
+  rate = rate * 1000;
+  rate /= _context->time_base.num;
 
-        _context->me_range=255; // Fix motion vector for picky players (pioneer)
+  _context->me_range = 255;	// Fix motion vector for picky players (pioneer)
 
   if (_id == FF_MPEG2)
     {
@@ -169,30 +225,31 @@ int rate;
     }
   if (_settingsPresence)
     {
-    	if(_settings.widescreen) 
+      if (_settings.widescreen)
 	{
-		_context->sample_aspect_ratio.num=16;
-		_context->sample_aspect_ratio.den=9;
+          printf("WideScreen\n");
+	  _context->sample_aspect_ratio.num = 16;
+	  _context->sample_aspect_ratio.den = 9;
 	}
-	else
+      else
 	{
-		_context->sample_aspect_ratio.num=4;
-		_context->sample_aspect_ratio.den=3;
+	  _context->sample_aspect_ratio.num = 4;
+	  _context->sample_aspect_ratio.den = 3;
 	}
 
       _context->rc_max_rate_header = _settings.maxBitrate * 8;	//1800*1000;// 2400 max, 700 min
-      _context->rc_buffer_size_header=_settings.bufferSize * 8 * 1024;
+      _context->rc_buffer_size_header = _settings.bufferSize * 8 * 1024;
       // If we don't have a maxrate, don't set buffer_size
-      if(1 && !_settings.override_ratecontrol) // FIXME
-      
-      {
-      		_context->rc_buffer_size = _context->rc_buffer_size_header;
-		_context->rc_max_rate    = _context->rc_max_rate_header;
-	}
-	else
+      if (1 && !_settings.override_ratecontrol)	// FIXME
+
 	{
-		_context->rc_buffer_size=0; // for xvid, no VBV so no ratecontrol
-		_context->rc_max_rate   = 0;
+	  _context->rc_buffer_size = _context->rc_buffer_size_header;
+	  _context->rc_max_rate = _context->rc_max_rate_header;
+	}
+      else
+	{
+	  _context->rc_buffer_size = 0;	// for xvid, no VBV so no ratecontrol
+	  _context->rc_max_rate = 0;
 	}
       _context->gop_size = _settings.gop_size;
 
@@ -201,7 +258,7 @@ int rate;
     {
       _context->rc_buffer_size = 200 * 8 * 1024;	// 40 for VCD  & 200 for SVCD
       _context->gop_size = _settings.gop_size;
-      
+
     }
   _context->rc_buffer_aggressivity = 1.0;
   _context->rc_initial_cplx = 3;
@@ -210,27 +267,29 @@ int rate;
 
   _context->scenechange_threshold = 0xfffffff;	// Don't insert I frame out of order
 
-  _frame.interlaced_frame=_settings.interlaced;
-  if (_settings.interlaced) 
-  	_frame.top_field_first=!_settings.bff;
-  
+  _frame.interlaced_frame = _settings.interlaced;
+  if (_settings.interlaced)
+    _frame.top_field_first = !_settings.bff;
+
 #if defined(CODEC_FLAG_INTERLACED_DCT)
   _context->flags |= _settings.interlaced ? CODEC_FLAG_INTERLACED_DCT : 0;
 #endif
 #if defined(CODEC_FLAG_INTERLACED_ME)
   _context->flags |= _settings.interlaced ? CODEC_FLAG_INTERLACED_ME : 0;
 #endif
-  
+
   //
   //_context->dsp_mask= FF_MM_FORCE;
   printf ("Mpeg12 settings:\n____________\n");
-  printf ("FF Max rate   (header) : %lu kbps\n", (_context->rc_max_rate_header) / 1000);
-  printf ("FF Buffer Size(header) : %lu bits / %lu kB\n", (_context->rc_buffer_size_header),
+  printf ("FF Max rate   (header) : %lu kbps\n",
+	  (_context->rc_max_rate_header) / 1000);
+  printf ("FF Buffer Size(header) : %lu bits / %lu kB\n",
+	  (_context->rc_buffer_size_header),
 	  _context->rc_buffer_size_header / (8 * 1024));
   printf ("FF Max rate   (rc) : %lu kbps\n", (_context->rc_max_rate) / 1000);
-  printf ("FF Buffer Size(rc) : %lu bits / %lu kB\n", (_context->rc_buffer_size),
-	  _context->rc_buffer_size / (8 * 1024));
-  
+  printf ("FF Buffer Size(rc) : %lu bits / %lu kB\n",
+	  (_context->rc_buffer_size), _context->rc_buffer_size / (8 * 1024));
+
   printf ("FF GOP Size    : %lu\n", _context->gop_size);
   return 1;
 }
@@ -244,42 +303,48 @@ ffmpegEncoder::initContext (void)
   // player compatiblity               
   if (_id == FF_MPEG1 || _id == FF_MPEG2)
     gopMpeg1 ();
- // if (_id == FF_HUFF || _id == FF_FFV1)
-    _context->strict_std_compliance = -1;
+  // if (_id == FF_HUFF || _id == FF_FFV1)
+  _context->strict_std_compliance = -1;
+  if (_id == FF_HUFF || _id == FF_FFV1 ||_id == FF_FFHUFF )
+    _context->strict_std_compliance = -2;
+  
   switch (_id)
     {
     case FF_MPEG4:
-      WRAP_Open(CODEC_ID_MPEG4);
+      encoderMT ();
+      WRAP_Open (CODEC_ID_MPEG4);
       break;
     case FF_MSMP4V3:
-      WRAP_Open(CODEC_ID_MSMPEG4V3);
+      WRAP_Open (CODEC_ID_MSMPEG4V3);
       break;
     case FF_MPEG1:
-      WRAP_Open(CODEC_ID_MPEG1VIDEO);
+      encoderMT ();
+      WRAP_Open (CODEC_ID_MPEG1VIDEO);
       break;
     case FF_MPEG2:
-      WRAP_Open(CODEC_ID_MPEG2VIDEO);
+      encoderMT ();
+      WRAP_Open (CODEC_ID_MPEG2VIDEO);
       break;
     case FF_H263:
-      WRAP_Open(CODEC_ID_H263);
+      WRAP_Open (CODEC_ID_H263);
       break;
     case FF_H263P:
-      WRAP_Open(CODEC_ID_H263P);
+      WRAP_Open (CODEC_ID_H263P);
       break;
     case FF_HUFF:
-      WRAP_Open(CODEC_ID_HUFFYUV);
+      WRAP_Open (CODEC_ID_HUFFYUV);
       break;
     case FF_FFV1:
-      WRAP_Open(CODEC_ID_FFV1);
+      WRAP_Open (CODEC_ID_FFV1);
       break;
     case FF_MJPEG:
-      WRAP_Open(CODEC_ID_MJPEG);
+      WRAP_Open (CODEC_ID_MJPEG);
       break;
     case FF_FFHUFF:
-        WRAP_Open(CODEC_ID_FFVHUFF);
-        break;
+      WRAP_Open (CODEC_ID_FFVHUFF);
+      break;
     case FF_SNOW:
-      WRAP_Open(CODEC_ID_SNOW);
+      WRAP_Open (CODEC_ID_SNOW);
       break;
     default:
       ADM_assert (0);
@@ -293,7 +358,24 @@ ffmpegEncoder::initContext (void)
   return 1;
 
 }
+void
+ffmpegEncoder::encoderMT (void)
+{
+  uint32_t nbThread = 0;
 
+  nbThread = ADM_useNbThreads ();
+  if (nbThread )
+    {
+      printf ("[codec]Enabling MT encoder with %u threads\n", nbThread);
+      if (0 > avcodec_thread_init (_context, nbThread))
+	{
+	  printf ("[codec]Failed!!\n");
+	  return;
+	}
+      _isMT = 1;
+    }
+
+}
 /*
 		Set user selected matrices.
 
@@ -348,7 +430,7 @@ ffmpegEncoderCQ::init (uint32_t val, uint32_t fps1000, uint8_t vbr)
       _statfile = NULL;
 
     }
- _context->time_base= (AVRational){1000,fps1000};
+  _context->time_base = (AVRational)  {  1000, fps1000};
 /*
   _context->frame_rate_base = 1000;
   _context->frame_rate = fps1000;
@@ -359,44 +441,20 @@ ffmpegEncoderCQ::init (uint32_t val, uint32_t fps1000, uint8_t vbr)
   return initContext ();
 }
 
-uint32_t ffmpegEncoder::getCodedFrame(void)
+uint32_t ffmpegEncoder::getCodedFrame (void)
 {
-	return _last_coded_frame;
+  return _last_coded_frame;
 }
 
-uint8_t
-  ffmpegEncoderCQ::encode (ADMImage * in,
-			   uint8_t * out, uint32_t * len, uint32_t * flags)
+uint8_t ffmpegEncoderCQ::encode (ADMImage * in, ADMBitstream * out)
 {
-  int32_t sz = 0;
-  uint32_t f;
-  encodePreamble (in->data);
-
+  int32_t    sz = 0;
+  uint32_t    f;
+  uint8_t    r=0;
+  
   _frame.quality = (int) floor (FF_QP2LAMBDA * _qual + 0.5);
-
-  //_context->quality=_qual;
-
-  if ((sz = avcodec_encode_video (_context, out, _w * _h * 3, &_frame)) < 0)
-    return 0;
-  _last_coded_frame=_context->real_pict_num;
-  *len = (uint32_t) sz;
-  f = frameType ();
-  if (flags)
-    *flags = f;
-  res.is_key_frame = 0;
-  if (f == AVI_KEY_FRAME)
-    res.is_key_frame = 1;
-  res.texture_bits = _context->i_tex_bits + _context->p_tex_bits;
-  res.motion_bits = _context->mv_bits;
-  res.total_bits = sz * 8;	// bytes -> bits
-  res.quantizer = 2;
-  res.out_quantizer =
-    (int) floor (_context->coded_frame->quality / (float) FF_QP2LAMBDA);
-
-
-  //      printf("text : %d motion %d\n",res.texture_bits,res.motion_bits);
-
-
+  r=ffmpegEncoder::encode(in,out);
+  out->out_quantizer=_qual;
   if (_vbr)			// update for lavcodec internal
     {
       if (!_statfile)
@@ -428,8 +486,7 @@ _____________________________________________
 
 */
 
-uint8_t
-ffmpegEncoderCBR::init (uint32_t val, uint32_t fps1000)
+uint8_t ffmpegEncoderCBR::init (uint32_t val, uint32_t fps1000)
 {
 //       mpeg4_encoder
   //
@@ -439,9 +496,11 @@ ffmpegEncoderCBR::init (uint32_t val, uint32_t fps1000)
   mplayer_init ();
 /*  _context->frame_rate_base = 1000;
   _context->frame_rate = fps1000;*/
-_context->time_base= (AVRational){1000,fps1000};
- 
- _context->bit_rate = _br;
+  _context->time_base = (AVRational)
+  {
+  1000, fps1000};
+
+  _context->bit_rate = _br;
 
   printf ("--> br: %lu", _br);
 
@@ -449,80 +508,22 @@ _context->time_base= (AVRational){1000,fps1000};
 
 }
 
-uint8_t
-  ffmpegEncoderCBR::encode (ADMImage * in,
-			    uint8_t * out, uint32_t * len, uint32_t * flags)
-{
-  int32_t sz = 0;
-
-  encodePreamble (in->data);
-  _context->bit_rate = _br; // ???
-
-
-  if ((sz = avcodec_encode_video (_context, out, _w * _h * 3, &_frame)) < 0)
-    return 0;
-  _last_coded_frame=_context->real_pict_num;
-  *len = (uint32_t) sz;
-  if (flags)
-    *flags = frameType ();
-
-  res.total_bits = sz * 8;      // bytes -> bits
-  res.out_quantizer = (int) floor (_context->coded_frame->quality / (float) FF_QP2LAMBDA);
-
-  return 1;
-
-}
 
 //------------------------------------------------------------------------------
 //              VBR
 //------------------------------------------------------------------------------
-uint8_t
-  ffmpegEncoderVBR::encode (ADMImage * in,
-			    uint8_t * out, uint32_t * len, uint32_t * flags)
+uint8_t ffmpegEncoderVBR::encode (ADMImage * in, ADMBitstream * out)
 {
-  uint16_t q;
-  uint8_t kf;
+    uint16_t q;
+    uint8_t kf;
 
-  q = (*flags) >> 8;
-  kf = (*flags) & 1;
-
-  return encodeVBR (in, out, len, flags, q, kf);
+    q=out->in_quantizer;
+    _frame.quality = (int) floor (FF_QP2LAMBDA * q + 0.5);
+    return ffmpegEncoder::encode(in,out);
 
 }
-
-/*----------------------------- ffmpeg VBR , internal 2 pass engine --------------------*/
-uint8_t
-  ffmpegEncoderVBR::encodeVBR (ADMImage * in,
-			       uint8_t * out,
-			       uint32_t * len,
-			       uint32_t * flags, uint16_t nq,
-			       uint8_t forcekey)
-{
-  UNUSED_ARG (nq);
-  UNUSED_ARG (forcekey);
-  int32_t sz = 0;
-
-  encodePreamble (in->data);
-
-
-  if ((sz = avcodec_encode_video (_context, out, _w * _h * 3, &_frame)) < 0)
-    return 0;
-  _last_coded_frame=_context->real_pict_num;
-  *len = (uint32_t) sz;
-  if (flags)
-    *flags = frameType ();
-  res.out_quantizer =
-    (int) floor (_context->coded_frame->quality / (float) FF_QP2LAMBDA);
-  return 1;
-
-
-}
-
 /*
    			val is the average bitrate wanted, else it is useless
-
-
-
 */
 uint8_t
 ffmpegEncoderVBR::init (uint32_t val, uint32_t fps1000)
@@ -537,7 +538,7 @@ ffmpegEncoderVBR::init (uint32_t val, uint32_t fps1000)
 //   _context->frame_rate_base = 1000;
 //   _context->frame_rate = fps1000;
 
-_context->time_base= (AVRational){1000,fps1000};
+  _context->time_base = (AVRational)  {  1000, fps1000};
 
   /* If internal 2 passes mode is selected ... */
   _context->flags |= CODEC_FLAG_PASS2;
@@ -572,53 +573,15 @@ ffmpegEncoderVBR::~ffmpegEncoderVBR ()
 
 //--------------------- FFmpeg VBR, external Qzation engine ------------------
 uint8_t
-  ffmpegEncoderVBRExternal::encode (ADMImage * in,
-				    uint8_t * out,
-				    uint32_t * len, uint32_t * flags)
+ffmpegEncoderVBRExternal::encode (ADMImage * in, ADMBitstream * out)
 {
-  uint16_t q;
-  uint8_t kf;
-
-  q = (*flags) >> 16;
-  kf = (*flags) & 1;
-
-  return encodeVBR (in, out, len, flags, q, kf);
-
-}
-
-uint8_t
-  ffmpegEncoderVBRExternal::encodeVBR (ADMImage * in,
-				       uint8_t * out,
-				       uint32_t * len,
-				       uint32_t * flags,
-				       uint16_t nq, uint8_t forcekey)
-{
-  UNUSED_ARG (nq);
-  UNUSED_ARG (forcekey);
-  int32_t sz = 0;
-  uint32_t f;
-  encodePreamble (in->data);
-
-
-
-  //_frame.quality=nq;
-  _frame.quality = (int) floor (FF_QP2LAMBDA * nq + 0.5);
-  if ((sz = avcodec_encode_video (_context, out, _w * _h * 3, &_frame)) < 0)
-    return 0;
-  _last_coded_frame=_context->real_pict_num;
-  *len = (uint32_t) sz;
-  f = frameType ();
-  if (flags)
-    *flags = f;
-  res.out_quantizer =
-    (int) floor (_context->coded_frame->quality / (float) FF_QP2LAMBDA);
-  if (f == AVI_KEY_FRAME)
-    res.is_key_frame = 1;
-  else
-    res.is_key_frame = 0;
-  return 1;
-
-
+    uint8_t r;
+    uint32_t q;
+  q=out->in_quantizer;
+  _frame.quality = (int) floor (FF_QP2LAMBDA * q + 0.5);
+  r= ffmpegEncoder::encode(in,out);
+  out->out_quantizer=q;
+  return r;
 }
 
 
@@ -635,7 +598,7 @@ ffmpegEncoderVBRExternal::init (uint32_t val, uint32_t fps1000)
 
 /*  _context->frame_rate_base = 1000;
   _context->frame_rate = fps1000;*/
-  _context->time_base= (AVRational){1000,fps1000};
+  _context->time_base = (AVRational) {  1000, fps1000};
   _context->flags |= CODEC_FLAG_QSCALE;;
   _context->bit_rate = 0;
   _context->bit_rate_tolerance = 1024 * 8 * 1000;
@@ -804,18 +767,6 @@ ffmpegEncoder::init (uint32_t val, uint32_t fps1000, uint8_t sw)
   return init (val, fps1000);
 }
 
-uint8_t
-  ffmpegEncoder::encode (ADMImage * in, uint8_t * out, uint32_t * len,
-			 uint32_t * flags)
-{
-  UNUSED_ARG (in);
-  UNUSED_ARG (out);
-  UNUSED_ARG (len);
-  UNUSED_ARG (flags);
-  ADM_assert (0);
-  return 0;
-}
-
 //------------------------------
 uint8_t
 ffmpegEncoderHuff::init (uint32_t val, uint32_t fps1000, uint8_t vbr)
@@ -824,7 +775,9 @@ ffmpegEncoderHuff::init (uint32_t val, uint32_t fps1000, uint8_t vbr)
   UNUSED_ARG (vbr);
   mplayer_init ();
 
-_context->time_base= (AVRational){1000,fps1000};
+  _context->time_base = (AVRational)
+  {
+  1000, fps1000};
 //   _context->frame_rate_base = 1000;
 //   _context->frame_rate = fps1000;
 
@@ -835,35 +788,10 @@ _context->time_base= (AVRational){1000,fps1000};
 
   return initContext ();
 }
-
-
-
-uint8_t
-  ffmpegEncoderHuff::encode (ADMImage * in,
-			     uint8_t * out, uint32_t * len, uint32_t * flags)
-{
-  int32_t sz = 0;
-
-  encodePreamble (in->data);
-
-
-
-  //_context->quality=_qual;
-
-  if ((sz = avcodec_encode_video (_context, out, _w * _h * 3, &_frame)) < 0)
-    return 0;
-  _last_coded_frame=_context->real_pict_num;
-  *len = (uint32_t) sz;
-  if (flags)
-    *flags = AVI_KEY_FRAME;
-  res.is_key_frame = _frame.key_frame;
-  return 1;
-
-}
 //__________________________________
 //------------------------------
 uint8_t
-ffmpegEncoderFFHuff::init (uint32_t val, uint32_t fps1000, uint8_t vbr)
+  ffmpegEncoderFFHuff::init (uint32_t val, uint32_t fps1000, uint8_t vbr)
 {
   UNUSED_ARG (val);
   UNUSED_ARG (vbr);
@@ -871,7 +799,9 @@ ffmpegEncoderFFHuff::init (uint32_t val, uint32_t fps1000, uint8_t vbr)
 
 /*  _context->frame_rate_base = 1000;
   _context->frame_rate = fps1000;*/
-_context->time_base= (AVRational){1000,fps1000};
+  _context->time_base = (AVRational)
+  {
+  1000, fps1000};
 
   _context->bit_rate = 0;
   _context->bit_rate_tolerance = 1024 * 8 * 1000;
@@ -881,30 +811,6 @@ _context->time_base= (AVRational){1000,fps1000};
 }
 
 
-
-uint8_t
-  ffmpegEncoderFFHuff::encode (ADMImage * in,
-                             uint8_t * out, uint32_t * len, uint32_t * flags)
-{
-  int32_t sz = 0;
-
-  encodePreamble (in->data);
-
-
-
-  //_context->quality=_qual;
-
-  if ((sz = avcodec_encode_video (_context, out, _w * _h * 3, &_frame)) < 0)
-    return 0;
-  _last_coded_frame=_context->real_pict_num;
-  *len = (uint32_t) sz;
-  if (flags)
-    *flags = AVI_KEY_FRAME;
-  res.is_key_frame = _frame.key_frame;
-  return 1;
-
-}
-
 //_______________________________________
 uint8_t
 ffmpegEncoder::getExtraData (uint32_t * l, uint8_t ** d)
@@ -927,7 +833,9 @@ ffmpegEncoderFFV1::init (uint32_t val, uint32_t fps1000, uint8_t vbr)
   UNUSED_ARG (val);
   UNUSED_ARG (vbr);
   mplayer_init ();
-_context->time_base= (AVRational){1000,fps1000};
+  _context->time_base = (AVRational)
+  {
+  1000, fps1000};
 //   _context->frame_rate_base = 1000;
 //   _context->frame_rate = fps1000;
 
@@ -939,31 +847,6 @@ _context->time_base= (AVRational){1000,fps1000};
   return initContext ();
 }
 
-
-
-uint8_t
-  ffmpegEncoderFFV1::encode (ADMImage * in,
-			     uint8_t * out, uint32_t * len, uint32_t * flags)
-{
-  int32_t sz = 0;
-
-  encodePreamble (in->data);
-
-
-
-  //_context->quality=_qual;
-
-  if ((sz = avcodec_encode_video (_context, out, _w * _h * 3, &_frame)) < 0)
-    return 0;
-  _last_coded_frame=_context->real_pict_num;
-  *len = (uint32_t) sz;
-  if (flags)
-    *flags = AVI_KEY_FRAME;
-  res.is_key_frame = _frame.key_frame;
-  return 1;
-
-}
-
 /*---
 */
 uint8_t
@@ -982,7 +865,9 @@ uint8_t
 
 //   _context->frame_rate_base = 1000;
 //   _context->frame_rate = fps1000;
-_context->time_base= (AVRational){1000,fps1000};
+  _context->time_base = (AVRational)
+  {
+  1000, fps1000};
   _context->flags = CODEC_FLAG_QSCALE;
   _context->bit_rate = 0;
   _context->bit_rate_tolerance = 1024 * 8 * 1000;
@@ -994,28 +879,9 @@ _context->time_base= (AVRational){1000,fps1000};
 
 
 uint8_t
-  ffmpegEncoderFFMjpeg::encode (ADMImage * in,
-				uint8_t * out, uint32_t * len,
-				uint32_t * flags)
+ffmpegEncoderFFMjpeg::encode (ADMImage * in, ADMBitstream * out)
 {
-  int32_t sz = 0;
-
-  encodePreamble (in->data);
-
-
-
-//       _frame.quality=_qual;
   _frame.quality = (int) floor (FF_QP2LAMBDA * _qual + 0.5);
-
-
-  if ((sz = avcodec_encode_video (_context, out, _w * _h * 3, &_frame)) < 0)
-    return 0;
-  _last_coded_frame=_context->real_pict_num;
-  *len = (uint32_t) sz;
-  if (flags)
-    *flags = AVI_KEY_FRAME;
-  res.is_key_frame = _frame.key_frame;
-  return 1;
-
+  return ffmpegEncoder::encode(in,out);
 }
 #endif
